UserAdModel class

Constructors

UserAdModel({String? id, String? displayName, String? givenName, String? surname, String? userPrincipalName, String? mail, String? accessToken, String? expiresOn, List<String>? businessPhones, String? odataContext, String? jobTitle, String? mobilePhone, String? officeLocation, String? preferredLanguage})
UserAdModel.fromJson(Map<String, dynamic> json)
model user ad return model inf
factory

Properties

accessToken ↔ String?
getter/setter pair
businessPhones → List<String>?
final
displayName → String?
final
expiresOn ↔ String?
getter/setter pair
givenName → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
jobTitle → String?
final
mail → String?
final
mobilePhone → String?
final
odataContext → String?
final
officeLocation → String?
final
preferredLanguage → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
surname → String?
final
userPrincipalName → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>?
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited